==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebFilteringEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebFilteringEventArgsDetailDescription } from "./WebFilteringEventArgsDetailDescription";
/**
 * @hidden
 */
var WebFilteringEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringEventArgsDetailDescriptionMetadata, _super);
    function WebFilteringEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebFilteringEventArgsDetailDescriptionMetadata.a == null) {
            WebFilteringEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringEventArgsDetailDescriptionMetadata.c(WebFilteringEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebFilteringEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFilteringEventArgsDetailDescriptionMetadata.a);
        WebFilteringExpressionsTreeDescriptionMetadata.d(a);
    };
    WebFilteringEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:FilteringEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("FilteringExpressions", "ExportedType:WebFilteringExpressionsTree");
    };
    WebFilteringEventArgsDetailDescriptionMetadata.d = function (a) {
        WebFilteringEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebFilteringEventArgsDetail", function () { return new WebFilteringEventArgsDetailDescription(); });
        a.z("WebFilteringEventArgsDetail", WebFilteringEventArgsDetailDescriptionMetadata.a);
    };
    WebFilteringEventArgsDetailDescriptionMetadata.$t = markType(WebFilteringEventArgsDetailDescriptionMetadata, 'WebFilteringEventArgsDetailDescriptionMetadata');
    WebFilteringEventArgsDetailDescriptionMetadata.a = null;
    return WebFilteringEventArgsDetailDescriptionMetadata;
}(Base));
export { WebFilteringEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebFilteringEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDescriptionMetadata } from "./WebFilteringExpressionsTreeDescriptionMetadata";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebFilteringEventArgsDetailDescription } from "./WebFilteringEventArgsDetailDescription";
/**
 * @hidden
 */
var WebFilteringEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringEventArgsDetailDescriptionMetadata, _super);
    function WebFilteringEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebFilteringEventArgsDetailDescriptionMetadata.a == null) {
            WebFilteringEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringEventArgsDetailDescriptionMetadata.c(WebFilteringEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebFilteringEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFilteringEventArgsDetailDescriptionMetadata.a);
        WebFilteringExpressionsTreeDescriptionMetadata.d(a);
    };
    WebFilteringEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:FilteringEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("FilteringExpressions", "ExportedType:WebFilteringExpressionsTree");
    };
    WebFilteringEventArgsDetailDescriptionMetadata.d = function (a) {
        WebFilteringEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebFilteringEventArgsDetail", function () { return new WebFilteringEventArgsDetailDescription(); });
        a.ab("WebFilteringEventArgsDetail", WebFilteringEventArgsDetailDescriptionMetadata.a);
    };
    WebFilteringEventArgsDetailDescriptionMetadata.$t = markType(WebFilteringEventArgsDetailDescriptionMetadata, 'WebFilteringEventArgsDetailDescriptionMetadata');
    WebFilteringEventArgsDetailDescriptionMetadata.a = null;
    return WebFilteringEventArgsDetailDescriptionMetadata;
}(Base));
export { WebFilteringEventArgsDetailDescriptionMetadata };
